@@ -21,8 +21,6 @@ lr_parse_ttt <- function(filename) {
 
   content <- readLines(filename, skipNul = TRUE)
 
-  # The ID is always included as the first 9 characters in the comment line
-  specID <- gsub("([[:alnum:]]{9})-.*", "\\1", content[1])
   author <- NA_character_
 
   # FIXME: from what I undertand, this "timestamp" is abritrary since it
@@ -41,6 +39,10 @@ lr_parse_ttt <- function(filename) {
   average <- gsub("^Average: ([[:digit:]]+) scans$", "\\1", content[3])
   boxcar <- gsub("^Nr of pixels used for smoothing: ", "", content[4])
 
+  # The ID is also sometimes included in the first line (comment line) but not
+  # always so it's better not to rely on this.
+  specID <- gsub("^.*: ([[:alnum:]]{9}).*$", "\\1", content[5])
+
   # Avantes does not allow different values between measurements
   dark_inttime <- white_inttime <- scope_inttime <- inttime
   dark_average <- white_average <- scope_average <- average
